/* +--------------------------------------------------------------------------+
// 2002-2008 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: layout.css,v 1.55.4.2 2016-10-10 14:08:48 wlair Exp $
*/

/*
	Theme inspired by Launchpad : http://launchpad.net/ trademark of Canonical Ltd.
	Icons inspired by http://www.eicodesign.com/ all rights for Rokey Zhang	(for non commercial purpose)
	
	Ce theme a ete verifie sous IE6 et 7, Firefox 2 et 3.
	L'affichage n'a pu etre optimise pour IE6, car les :hover ne sont pas geres avec d'autres
	elements que les liens.
	
	> Les couleurs du theme sont interchangeable sans toucher aux icones, via
	le fichier rub_colours.css
*/

/* ---------------------------------------------------------------------------*/
/*                           	  ATTRIBUTS GENERAUX                          */
/*                                                                            */
/*  						attributs generaux de la page	  	   			  */
/*		     			html / body / frames / liens a / img           		  */
/* ---------------------------------------------------------------------------*/
html{height:100%;}

body{
	height:100%;
	padding:0 1px;
	color:#000;
	font-size:13px;
	font-family:Arial,Helvetica,Sans-serif;
	background:white;
	margin:0;
}

iframe{
	border:1px solid #bbb;
}

iframe#alerte { 
	visibility:visible;
	position:absolute;
	left:0;
	top:600px;
	width:150px;
	border-style:none;
	border-width:0px;
	border-color:#000000;f9bd5d
	background:transparent;
}

a {
	color: #00F;
	text-decoration:underline;
}

a:hover{color: #009;}
.lien_gestion{
	color:#000;
	text-decoration:none;	
}

.lien_gestion:hover{
	color:#0000ff;
	text-decoration:underline;	
}

h3{
	clear: both;
	display: block;
	margin-bottom: 2px;
	margin-top: 4px;
	padding-bottom: 1px;
	padding-top: 1px;
	font-size: 13px;
}

img {
	margin:0px;
	vertical-align: middle;
	border: none;
}

select,input{
	background:white;
	-moz-border-radius : 3px;
	-webkit-border-radius:3px;
	border-radius:3px;
	vertical-align:middle;
}
/* ---------------------------------------------------------------------------*/
/*                         BARRE DE NAGIVATION                                */
/*                                                                            */
/* 			      #navbar / #extra  		              					  */
/* ---------------------------------------------------------------------------*/

#navbar{
	background:white;
	padding-top:15px;
	padding-bottom:26px;
	padding-left:80px;
}
	#navbar h3{
		display:none;
	}
		#navbar h3 span{
			font-size:14px;
			position:relative;
			top:-50px;
			padding-left:5px;
			color:#ddd;
			display:none;
		}
	#navbar ul{
		position:absolute;
		list-style-type:none;
		margin:1px 0 0 0;
	}
		#navbar li{
			margin-right:2px;	
		}
	/*
	 * Habillage des li
	 * On veillera a utiliser un sprite css uniquement pour les navigateurs n'ayant pas besoin 
	 * du hack de transparence "behavior" (incompatibilit� avec les background position)
	 * Le sprite trouve son utilit� pour la mise en cache d'une seule image 
	 * <=> pas de chargement sur le :hover
	*/
	#navbar-dashboard,
	#navbar-opac,
	#navbar-index,
	#navbar-circ,
	#navbar-catalog,
	#navbar-autorites,
	#navbar-edit,
	#navbar-dsi,
	#navbar-acquisition,
	#navbar-admin,
	#navbar-cms,
	#navbar-extensions,
	#navbar-demandes,
	#navbar-fichier{
		float:left;
		display:block;
		width:auto!important;
		width:10px;
		background-repeat:no-repeat;
		background:url('images/navbar.png');
		background-position:top right;
		height:25px;
	}
	
	ul>#navbar-dashboard,
	ul>#navbar-opac,
	ul>#navbar-index,
	ul>#navbar-circ,
	ul>#navbar-catalog,
	ul>#navbar-autorites,
	ul>#navbar-edit,
	ul>#navbar-dsi,
	ul>#navbar-acquisition,
	ul>#navbar-admin,
	ul>#navbar-cms,
	ul>#navbar-extensions,
	ul>#navbar-demandes,
	ul>#navbar-fichier{
		background-image:url('images/navbar_sprite.png');
		background-position:100% 0;
	}
	
	/*
	 * Habillage des li:hover
	*/
	#navbar-dashboard:hover,
	#navbar-opac:hover,
	#navbar-index:hover,
	#navbar-circ:hover,
	#navbar-catalog:hover,
	#navbar-autorites:hover,
	#navbar-edit:hover,
	#navbar-dsi:hover,
	#navbar-acquisition:hover,
	#navbar-admin:hover,
	#navbar-cms:hover,
	#navbar-extensions:hover,
	#navbar-demandes:hover,
	#navbar-fichier:hover{
		background-image:url('images/navbar_hover.png');
		background-repeat:no-repeat;
		background-position:top right;
		
		/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
		behavior:url('styles/nova/iepngfix.htc');
	}
	ul>#navbar-dashboard:hover,
	ul>#navbar-opac:hover,
	ul>#navbar-index:hover,
	ul>#navbar-circ:hover,
	ul>#navbar-catalog:hover,
	ul>#navbar-autorites:hover,
	ul>#navbar-edit:hover,
	ul>#navbar-dsi:hover,
	ul>#navbar-acquisition:hover,
	ul>#navbar-admin:hover,
	ul>#navbar-cms:hover,
	ul>#navbar-extensions:hover,
	ul>#navbar-demandes:hover,
	ul>#navbar-fichier:hover{
		background-image:url('images/navbar_sprite.png');
		background-position:100% -50px;
	}
	
	/*
	* Habillage des li.current
	*/	
	#navbar-dashboard.current,
	#navbar-opac.current,
	#navbar-index.current,	
	#navbar-circ.current,
	#navbar-catalog.current,	
	#navbar-autorites.current,	
	#navbar-edit.current,	
	#navbar-dsi.current,	
	#navbar-acquisition.current,	
	#navbar-admin.current,
	#navbar-cms.current,
	#navbar-extensions.current,
	#navbar-demandes.current,
	#navbar-fichier.current{
		background-image:url('images/navbar_current.png');
		background-repeat:no-repeat;
		background-position:top right;
		height:27px;
		
		/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
		behavior:url('styles/nova/iepngfix.htc');
	}
	
	ul>#navbar-dashboard.current,
	ul>#navbar-opac.current,
	ul>#navbar-index.current,	
	ul>#navbar-circ.current,
	ul>#navbar-catalog.current,	
	ul>#navbar-autorites.current,	
	ul>#navbar-edit.current,	
	ul>#navbar-dsi.current,	
	ul>#navbar-acquisition.current,	
	ul>#navbar-admin.current,
	ul>#navbar-cms.current,
	ul>#navbar-extensions.current,
	ul>#navbar-demandes.current,
	ul>#navbar-fichier.current{
		background-image:url('images/navbar_sprite.png');
		background-position:100% -100px;
	}
		/* 
		* Habillage des liens a 
		*/
		#navbar-dashboard a,
		#navbar-opac a,
		#navbar-index a,
		#navbar-circ a,
		#navbar-catalog a,
		#navbar-autorites a,
		#navbar-edit a,
		#navbar-dsi a,
		#navbar-acquisition a,
		#navbar-admin a,
		#navbar-cms a,
		#navbar-extensions a,
		#navbar-demandes a,
		#navbar-fichier a{
			height:17px;
			display:block;
			padding:6px 10px 2px 10px;
			text-decoration:none;
			color:#000;
			background-image:url('images/navbar_bord.png');
			background-repeat:no-repeat;	
		}
		#navbar-dashboard>a,
		#navbar-opac>a,
		#navbar-index>a,
		#navbar-circ>a,
		#navbar-catalog>a,
		#navbar-autorites>a,
		#navbar-edit>a,
		#navbar-dsi>a,
		#navbar-acquisition>a,
		#navbar-admin>a,
		#navbar-cms>a,
		#navbar-extensions>a,
		#navbar-demandes>a
		#navbar-fichier>a{
			background-image:url('images/navbar_sprite.png');
			background-position:0px -25px;
		}
		/* 
		* Habillage des liens a.current
		*/
		#navbar-dashboard>a:hover,
		#navbar-index>a:hover,
		#navbar-opac>a:hover,
		#navbar-circ>a:hover,
		#navbar-catalog>a:hover,
		#navbar-autorites>a:hover,
		#navbar-edit>a:hover,
		#navbar-dsi>a:hover,
		#navbar-acquisition>a:hover,
		#navbar-admin>a:hover,
		#navbar-cms>a:hover,
		#navbar-extensions>a:hover,
		#navbar-demandes>a:hover,
		#navbar-fichier>a:hover{
			background-image:url('images/navbar_sprite.png');
			background-position:0px -75px;
			background-repeat:no-repeat;
			/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
			behavior:url('styles/nova/iepngfix.htc');
		}
		
		#navbar-dashboard a:hover,
		#navbar-index a.current,
		#navbar-opac a.current,
		#navbar-circ a.current,
		#navbar-catalog a.current,
		#navbar-autorites a.current,
		#navbar-edit a.current,
		#navbar-dsi a.current,
		#navbar-acquisition a.current,
		#navbar-admin a.current,
		#navbar-cms a.current,
		#navbar-extensions a.current,
		#navbar-demandes a.current,
		#navbar-fichier a.current{
			background-image:url('images/navbar_current_bord.png');
			background-repeat:no-repeat;
			/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
			behavior:url('styles/nova/iepngfix.htc');
			height:19px;
		}
		
		#navbar-dashboard>a.current,
		#navbar-index>a.current,
		#navbar-opac>a.current,
		#navbar-circ>a.current,
		#navbar-catalog>a.current,
		#navbar-autorites>a.current,
		#navbar-edit>a.current,
		#navbar-dsi>a.current,
		#navbar-acquisition>a.current,
		#navbar-admin>a.current,
		#navbar-cms>a.current,
		#navbar-extensions>a.current,
		#navbar-demandes>a.current,
		#navbar-fichier>a.current{
			background-image:url('images/navbar_sprite.png');
			background-position:0px -127px;
		}

#extra{
	position:absolute;
	top:3px;
	right:15px;
	height:30px;
	font-weight:bold;
	color:#728085;
	padding:0;
	margin:0;
	display:block;
}
	#extra img{display:none;}
	
	/* Ppts generales des icones #extra */
	#extra .icon_history,
	#extra .icon_help,
	#extra .icon_param,
	#extra .icon_opac,
	#extra .icon_sauv,
	#extra .icon_quit{
		width:26px;
		height:25px;
		display:block;
		float:left;
		margin:0px 3px;
		background-repeat:no-repeat;
		cursor:pointer;
		/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
		behavior:url('styles/nova/iepngfix.htc');
	}
	
	#extra .icon_history{background-image:url('images/icon_history.png');}
	#extra .icon_help{background-image:url('images/icon_help.png');}
	#extra .icon_param{background-image:url('images/icon_param.png');}
	#extra .icon_opac{background-image:url('images/icon_opac.png');}
	#extra .icon_sauv{background-image:url('images/icon_sauv.png');}
	#extra .icon_quit{background-image:url('images/icon_quit.png');}
	
	/*
		* Red�finition des ppts generales pour navigateurs recents
		* permet ainsi l'usage de sprites pour all�ger les requ�tes serveur
		* enleve l'interpretation inutile de 'behaviour' par iE7
	*/
	#extra>.icon_history,
	#extra>.icon_help,
	#extra>.icon_param,
	#extra>.icon_opac,
	#extra>.icon_sauv,
	#extra>.icon_quit{
		background-image:url('images/icon_sprite.png');
		behavior:none;
	}
	#extra>.icon_history{background-position:0 0;}
	#extra>.icon_help{background-position:0 -25px;}
	#extra>.icon_param{background-position:0 -50px;}
	#extra>.icon_opac{background-position:0 -75px;}
	#extra>.icon_sauv{background-position:0 -100px;}
	#extra>.icon_quit{background-position:0 -125px;}


	#keystatus{
		font-weight:bold;
		position:absolute;
		top:0px;
		overflow:hidden;
	}

	/* General bouton plus/moins */
	.img_plus{
		background:#ddd;
		margin:0 0 -1px 0;
		cursor:pointer;		
		/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
		behavior:url('styles/nova/iepngfix.htc');
	}
	
	
/* ---------------------------------------------------------------------------*/
/*                                CONTENEUR		                      		  */
/*                                                                            */
/* 			      			#conteneur / #menu	 		              		  */
/* ---------------------------------------------------------------------------*/

#conteneur{
	-moz-border-radius:6px;
	-webkit-border-radius:6px;
	border-radius:6px;
	display:block;
	min-height:100%;
	height:auto !important;
	height:100%;
	width:100%;
	padding-bottom:20px;
}
#conteneur.extensions{
	min-height:0%;	
}
.index #noconteneur{
	background:#ede9e3;
	position:absolute;
	min-height:100%;
	height:auto !important;
	height:100%;
	width:100%;
}

/* -------- Menu ---------- */
#menu{
	position:absolute;
	left:0px;
	margin-top:18px;
	padding:3px 20px 9px 15px;
	width:150px;
	background-image:url("images/menu_fond.png");
	background-repeat:no-repeat;
	background-position:25px 100%;
}
	#menu h3{
		width:130px;
		height:18px;
		display:block;
		margin:0px;
		padding:5px 0px 0px 20px;
		color:white;
		font-size:12px;
		cursor:pointer;
		background-image:url("images/menu_h3_deplie.png");
		background-repeat:no-repeat;
		/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
		behavior:url('styles/nova/iepngfix.htc');
	}
	/* classe ajoutee lors du repliement de l'element */
	#menu h3.selected{
		background-image:url("images/menu_h3_selected.png");
		background-repeat:no-repeat;
	}
	/* classe ajoutee lors de l'enregistrement des preferences de disposition */
	#menu h3.setpref{
		background-image:url("images/menu_h3_setpref.png");
		background-repeat:no-repeat;
	}
	
	/*
		* Red�finition des ppts generales pour navigateurs recents
		* permet ainsi l'usage de sprites pour all�ger les requ�tes serveur
		* enleve l'interpretation inutile de 'behaviour' par iE7
	*/
	#menu>h3{
		behavior:none;
		background-image:url("images/menu_h3_sprite.png");
		background-repeat:no-repeat;
	}
	/* classe ajoutee lors du repliement de l'element */
	#menu>h3.selected{
		background-image:url("images/menu_h3_sprite.png");
		background-position:0px -23px;
	}
	/* classe ajoutee lors de l'enregistrement des preferences de disposition */
	#menu>h3.setpref{
		background-image:url("images/menu_h3_sprite.png");
		background-position:0px -46px;
	}

	#menu ul{
		list-style-type:none;
		padding:0 1px;
		margin:0 10px;
		display:block;
		border-left:1px solid #aaa;
		border-right:1px solid #aaa;
	}
	#menu li{
		padding:1px 0;
		font-size:12px;
	}
			#menu li a{
				display:block;
				color:#000;
				padding:3px 5px 3px 10px;
				text-decoration:none;
				-moz-border-radius : 2px;
			}
			#menu li a:hover{
				color:white;
				background:#756d6c url("images/menu_liens_hover.png") repeat-x;
			}
	#menu hr{margin:0;}
	#div_alert{
		margin:0 10px;
		padding:0 3px;
		border-left:1px solid #aaa;
		border-right:1px solid #aaa;
	}
	#div_alert ul{
		padding: 5px 0;
		border:none;
	}

/* ---------------------------------------------------------------------------*/
/*                                CONTENU		                      		  */
/*                                                                            */
/* 			      			#contenu / .hmenu        						  */
/* ---------------------------------------------------------------------------*/
#contenu{
	padding-top:10px;
	margin-left:195px;
	padding-right:40px;
}
	#contenu-frame{
		background:#e6e1da;
		padding:10px;
	}
	#contenu .hmenu{
		margin-bottom:10px;
		margin-left:20px;
		padding-right:15px;
		display:table;
		width:100%;
		position:relative;
		left:-16px;
		height:22px;
	}
		.hmenu span{
			display:block;
			float:left;
			margin-right:-16px;
			background-image:url('images/hmenu_item.png');
			background-repeat:no-repeat;
			/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
			behavior:url('styles/nova/iepngfix.htc');
		}
		.hmenu span:hover,
		.hmenu span.selected{
			background-image:url('images/hmenu_item_selected.png');
		}
			.hmenu span a{
				display:block;
				color:#777;
				text-decoration:none;
				float:left;
				padding-left:22px;
				padding-right:22px;
				padding-top:6px;
				height:21px;
				background-repeat:no-repeat;
			}

		/*
			* Red�finition des ppts pour les navigateurs recents
			* permet ainsi l'usage de sprites pour all�ger les requ�tes serveur
			* enleve l'interpretation inutile de 'behaviour' par iE7	
		*/
		.hmenu>span{
			background-image:url('images/hmenu_sprite.png');
			behavior:none;
		}	
		.hmenu>span:hover,
		.hmenu>span.selected{
			background-image:url('images/hmenu_sprite.png');
			background-position:0px -54px;
			behavior:none;
			color:#111;
		}
			.hmenu>span a{
				background-image:url('images/hmenu_sprite.png');
				background-position:100% -27px;
				behavior:none;
			}
			.hmenu>span a:hover,
			.hmenu>span.selected a{
				background-image:url('images/hmenu_sprite.png');
				background-position: 100% -81px;
				behavior:none;
			}
		.vmenu span{
			display:block;
			background-image:url('images/hmenu_item.png');
			background-repeat:no-repeat;
			/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
			behavior:url('styles/nova/iepngfix.htc');
		}
		.vmenu span:hover,
		.vmenu span.selected{
			background-image:url('images/hmenu_item_selected.png');
		}
			.vmenu span a{
				display:block;
				color:#777;
				text-decoration:none;
					padding-left:22px;
				padding-top:6px;
				height:21px;
				background-repeat:no-repeat;
			}

		/*
			* Red�finition des ppts pour les navigateurs recents
			* permet ainsi l'usage de sprites pour all�ger les requ�tes serveur
			* enleve l'interpretation inutile de 'behaviour' par iE7	
		*/
		.vmenu>span{
			background-image:url('images/hmenu_sprite.png');
			behavior:none;
		}	
		.vmenu>span:hover,
		.vmenu>span.selected{
			background-image:url('images/hmenu_sprite.png');
			background-position:0px -54px;
			behavior:none;
			color:#111;
		}
			.vmenu>span a{
				background-image:url('images/hmenu_sprite.png');
				background-position:100% -27px;
				behavior:none;
			}
			.vmenu>span a:hover,
			.vmenu>span.selected a{
				background-image:url('images/hmenu_sprite.png');
				background-position: 100% -81px;
				behavior:none;
			}
	h1{
		font-size:16px;
		color:#333;
	}
	#contenu h2, #contenu h3{
		font-size:13px;
		color:#444;
		padding:8px 0 0 14px;
		margin:5px 0;
		min-height:12px;
		height:auto !important;
		height:12px;
	}
	#contenu h3{
		-moz-border-radius:4px;
		-webkit-border-radius:4px;
		border-radius:4px;
		padding-bottom:6px;
	}
	#contenu h3 img{
		margin-right:3px;
		position:relative;
		top:2px;
	}

/* ------------------ formulaires --------------- */	

	form {
		width: 100%;
		padding:5px;
		margin:20px auto;
		background:#eee;
		-moz-border-radius:10px;
		-webkit-border-radius:10px;
		border-radius:10px;
	}
	.row{
		margin:4px 0;
		clear:both;
	}
	.separateur{
		border-bottom:1px solid #444;
	}
.form-contenu {
		border-bottom: 2px solid #CCCCCC;
		border-top: 2px solid #CCCCCC;
		padding: 5px;
		margin:10px 40px;
		padding-bottom: 1em;
		padding-top: 1em;
	}
		.form-contenu label{
			color:#2e3436;
			font-weight:bold;
		}
		.form-contenu td{
			margin:0;
			padding:0;
			border:none;
		}
	.form-clean{margin:0}
	.saisie-contenu, #contenu .astuce{
		font-size:11px;
		display:block;
		margin:10px 0;
		padding:10px 10px;
		background:#f1ece6;
		border:1px solid #d0ccc6;
		clear:both;
		-moz-border-radius:6px;
		-webkit-border-radius:6px;
		border-radius:6px;
	}
	#contenu ul{
		margin:10px 0 10px 30px;
	}
	#contenu li{
		padding:5px 2px;
	}
	#conteneur.extensions #contenu ul{
		margin: 10px;
	}
	table{
		margin:10px 0;
		border-collapse: collapse;
		width:100%;
	}
	tr {font-style: normal;}
	td.docnum{text-align: center;}
	tr.odd{background:#eee;}
	tr.even{background:#e5e5e5;}
	tr.surbrillance{background:#d3d3d3;}
	tr.justmodified{
	background:#939393;
	font-weight: bold;
	}
	td{
		border:1px solid #ccc;
		padding:3px 10px;
	}
	td a{
		text-decoration:none;
		color:#000;
	}
	#contenu-frame td{border:none;}
	th{
		border:1px solid #aaa;
		padding:3px 10px;
		background:#ccc;
	}

/*
	select{padding:1px 2px;}
	option{padding:0 5px;}

	.usercheckbox{padding:0 6px;}
		.usercheckbox label{margin:-4px 0 0 3px;}
*/
	hr{
		width:100%;
		display:block;
		clear:both;
		margin:15px 0;
		border-top:1px solid #cac1b3;
		border-bottom:1px solid #fff;
		color: #ffffff;
		height: 2px;
	}
	ul{margin-left:10px;}
	ol{margin-left:20px;}
	
	
/* ------------ Login-box ---------------*/

#login-box{
	width: 60%;
	margin-left: 20%;
	margin-right: 20%;
	margin-top: 10%;
	background:#f4f0ea;
	-moz-border-radius:10px;
	-webkit-border-radius:10px;
	border-radius:10px;
	padding:0;
	padding-bottom:15px;
}
#login-box .erreur{
	padding-left:20px;	
}
#noconteneur form{
	margin:0;
	background:none;	
}
#noconteneur .bouton{
	margin-top:10px;
	margin-left:10px;
}
#login-box h1{
	color:#3a4244;
	border-left:2px solid #ffa619;
	border-bottom:1px solid #bbb;
	border-top:1px solid #ddd;
	border-right:1px solid #ddd;
	padding:3px 0 3px 10px;
	background:#f8f5f0;
	-moz-border-radius:3px;
	-webkit-border-radius:3px;
	border-radius:3px;
	margin:0;
}
#noconteneur .form-contenu{margin-top:0px;}
#login-box label{
	font-size: 9pt;
	font-weight: bold;
}
#noconteneur #footer{
	padding:9% 0 10px 35px;
	margin:0;
	clear:both;
	background:#ede9e3;
}

/* ------------- logo --------------- */

#logo{
	position: absolute;
    bottom: 0;
    left: -60px;
    /*background: transparent no-repeat bottom right url("books_small.gif");*/
    padding: 5px;
    margin: 0px auto;
    width: 200px;
    height:150px;
    z-index: 0;
}
      
#logo span{display:none;}

/* --------------------------- */

.col{
	float: left;
	width: 100%;
	padding: 1em;
	margin: 1em;
}
.erreur{
	color: #f00;
	font-weight: bold;
	font-size: 16px;
}
.erreur-child{
	display:none;
	margin-left: 12%;
	padding:0;
	color:#000;
	font-weight:normal;
}	
.hide {display: none;}
.aide{cursor: help;}
.astuce{ 	
	font-size: 10pt;
	margin-top: 1em;
}
.bool{
	font-family: fixed;
	font-weight: bold;
}

.bouton, .bouton_small{
	-moz-border-radius:6px;
	-webkit-border-radius:6px;
	border-radius:6px;
	background:#666;
	color:white;
	border:1px outset #aaa;
}
.bouton:hover, .bouton_small:hover{
	border:1px inset #aaa;
	cursor:pointer;
}

.spacer{clear: both;
	visibility: hidden;
	display: none;
	margin-bottom: -10px;
	margin-top: -10px;
}



/* -----------------------------------------------------------------------------*/
/* 																				*/
/*                            CLASSES LIEES A L'APPLICATION                     */
/*                                                                              */
/*  feuilles de styles appliqu�es � des balises sans classes ni id sp�cifi�s    */
/* 																				*/
/* -----------------------------------------------------------------------------*/


.notice-perio{
	border: 1px solid #ddd;
	-moz-border-radius:6px;
	-webkit-border-radius:6px;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;
}
#content_onglet_perio{
	margin-left:20px;
	margin-bottom:37px;
}
	#content_onglet_perio span{
		display:block;
		width:auto!important;
		width:10px;
		height:25px;
		float:left;
		margin-bottom:25px;
		margin-right:2px;
		cursor:pointer;
	}
	#content_onglet_perio a{
		height:17px;
		display:block;
		padding:6px 10px 2px 10px;
		text-decoration:none;
		color:#000;
		text-align:center;
	}
.onglets-perio{
	background-repeat:no-repeat;
	background-image:url('images/navbar.png');
	background-position:top right;	
}
	.onglets-perio a{	
		background-image:url('images/navbar_bord.png');
		background-repeat:no-repeat;
	}
#content_onglet_perio>.onglets-perio{
	background-image:url('images/navbar_sprite.png');
	background-position:100% 0px;	
}
	.onglets-perio>a{	
		background-image:url('images/navbar_sprite.png');
		background-position:0px -25px;
	}
.onglet-perio-selected {
	background-color:#F99C09;
	background-repeat:no-repeat;
	background-image:url('images/navbar_current.png');
	background-position:top right;
	cursor:default;
	/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
	behavior:url('styles/nova/iepngfix.htc');
}
	.onglet-perio-selected a{	
		background-image:url('images/navbar_current_bord.png');
		background-repeat:no-repeat;
		/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
		behavior:url('styles/nova/iepngfix.htc');
	}
	
#content_onglet_perio>.onglet-perio-selected{
	background-image:url('images/navbar_sprite.png');
	background-position:100% -100px;
}
	.onglet-perio-selected>a{	
		background-image:url('images/navbar_sprite.png');
		background-position:0px -127px;
	}

.bulletins-perio{
	border: 1px solid #ddd;
	-moz-border-radius:6px;
	-webkit-border-radius:6px;
	padding: 1em;
	margin-bottom: 1em;
}

.bulletins-perio h2 blockquote {
	font-size:0.8em;
	font-weight: normal;
}	
.depouillements-perio{
	border: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;
}
.msg-perio {
	font-size: 150%;
	font-weight: bold;
	color: #f00;
}
	
/* barre fl�ch�e en p�rio */
.perio-barre {
	font-size: 120%;
	font-weight: bold;
}

/* classes pour l'affichage de liste d�pliantes en r�sultat de recherche */
.notice-heada {
	text-decoration: none;
	font-size: 10pt;
	font-weight: bold;
}
.notice-parent {
	color: #000000;
	margin-bottom: 7px;
	margin-top: 7px;
	text-decoration: none;
}
.notice-parent img {
	vertical-align: bottom;
}
.notice-parent a{
	font-weight:normal;
	color:#000;
}
.notice-child {
	font-size: 0.9em;
	margin-left: 30px;
	margin-bottom: 15px;
	margin-top:5px;
	width: 98%;
	padding: 0 6px;
	text-align: justify;
	background:#f6f2ec;
	border: 1px solid #bbb;
	-moz-border-radius:6px;
	-webkit-border-radius:6px;
	border-radius:6px;
}

.notice-child table td img.img_notice {
    max-width: 140px;
	max-height: 200px;
	width: expression(this.width > 140 ? "140px" : true);
	height: expression(this.height > 200 ? "200px" : true);
}

table td .img_notice {
    max-width: 140px;
	max-height: 200px;
	width: expression(this.width > 140 ? "140px" : true);
	height: expression(this.height > 200 ? "200px" : true);
}

.notice-child .expl-list{border:1px solid #999;}

.notice-child td,.notice-child th{border:none;}

.notice-bu {
	margin-top: 0px;
	background-color: transparent;
	border-style: none;
}

/* classes pour l'affichage de liste d�pliantes en formulaire de saisie de notice */
.heada {
	font-size: 10pt;
	font-weight: bold;
	padding-left:3px;
}
.parent {
	color: #000000;
	margin-left:0px;
	font-size: 8pt;
	text-decoration: none;
	clear:both;
}
.child {
	margin-left: 30px;
}
.bu {
	margin-top: 15px;
}

.titre-panier{
	border: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;
}

#history_table {
	border:0px;
	padding:0px;
	margin:0px;
	background:transparent;
}

#history_table td {
	padding:0px;
	margin:0px;
	border:0px;
}
#contenu .parent h3 img{
	float:left;
	margin-top:-1px;
}
#addaut1,#addaut2{
	margin:5px 0 0 2px;
}
/* -----------------------------------------------------------------------------*/
/* 																				*/
/*                       MODIFICATIONS POUR L'IMRPESSION                        */
/*                                                                              */
/* pour l'impression, masquage de #navbar, #menu, #deconnexion, #extra,         */
/* iframe#alerte et des boutons de classe .bouton; #contenu coll�s à gauche   */
/* 																				*/
/* -----------------------------------------------------------------------------*/


@media print {
	#conteneur{
			position: relative;
			clear:both;
	}

	#navbar{ display: none; }
	#menu{ display: none;}

	/*	Menu	*/
	#deconnexion{ display: none; }
	#extra{ display: none; }
	.bouton{ display:none; }
  	.bouton_small{ display:none; }

	iframe#alerte{ visibility:hidden;}
}

iframe#history {
	width:40%;
	height:97%;
	position:absolute; 
	top:1%; 
	left:1%;
	z-index:1000;
}
* HTML iframe#history {
	height:580px;
}
/* pour affichage de pav�s de couleur pour disinction des statuts de notices */
.statutnot1 {}
.statutnot2 {background-color: #BB0000;}
.statutnot3 {background-color: #00BB00;}
.statutnot4 {background-color: #0000BB;}
.statutnot5 {background-color: #D0686F;}
.statutnot6 {background-color: #A6DCDC;}
.statutnot7 {background-color: #816492;}
.statutnot8 {background-color: #BCB964;}
.statutnot9 {background-color: #6C75AC;}
.statutnot10 {background-color: #FFC587;}
.statutnot11 {background-color: #70C173;}
.statutnot12 {background-color: #660000;}
.statutnot13 {background-color: #006600;}
.statutnot14 {background-color: #000066;}
.statutnot15 {background-color: #80181F;}
.statutnot16 {background-color: #668C8C;}
.statutnot17 {background-color: #311442;}
.statutnot18 {background-color: #7C7914;}
.statutnot19 {background-color: #2C356C;}
.statutnot20 {background-color: #BF8547;}

.gris {color:#ccc;}
.message_important {
	color: #f00;
	font-weight: bold;
	font-size: 1.5em;
	padding:5px;
	margin:5px;
}
body.select{background:#e6e1da;}
body.select .row{
	background:#e6e1da;
	margin:0;
	padding:5px 15px;
}
ul.sel_navbar {
	margin:5px;
	padding:0;
	list-style:none;
	clear:right;
	height:21px;
	float:left;
	margin-bottom:4px;
}
ul.sel_navbar li {
	float:left;
	display:block;
	width:auto!important;
	width:10px;
	background-repeat:no-repeat;
	background:url('images/navbar.png');
	background-position:top right;
}
ul.sel_navbar li a {
	text-decoration:none;
	font-weight:normal;
	color:#000000;
	height:17px;
	display:block;
	padding:6px 10px 2px 10px;
	text-decoration:none;
	color:#000;
	background-image:url('images/navbar_bord.png');
	background-repeat:no-repeat;	
}
ul.sel_navbar li.sel_navbar_current {
	background-image:url('images/navbar_current.png');
	background-repeat:no-repeat;
	background-position:top right;
	height:24px;
	
	/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
	behavior:url('styles/nova/iepngfix.htc');
}
ul.sel_navbar li.sel_navbar_current a {
	background-image:url('images/navbar_current_bord.png');
	background-repeat:no-repeat;
	/* Gestion des png transparents (multi-niveaux) sous IE5.5 et 6 */
	behavior:url('styles/nova/iepngfix.htc');
	height:17px;
}

.dsi table.dsi tr td:hover {background:#dc3400;}

#frame_notice_preview {
	display:none;
	border:2px solid #777799;
	-moz-border-radius:10px;
	-webkit-border-radius:10px;
	border-radius:10px;
	padding:10px;
	z-Index:1000;
	position:absolute;
	background: #eee;
	width:680px;
	height:500px;
}

#up_frame{
	display:none;
	border:2px solid #777799;
	-moz-border-radius:10px;
	-webkit-border-radius:10px;
	border-radius:10px;
	padding:10px;
	z-Index:1000;
	position:absolute;
	background: #eee;
}

#frame_periodique {
	display:none;
	border:2px solid #777799;
	-moz-border-radius:10px;
	-webkit-border-radius:10px;
	border-radius:10px;
	padding:10px;
	z-Index:1000;
	position:absolute;
	background: #eee;
	width:190px;
	height:250px;
}


#expl-form select {
	width: 195px;
}

	body.pointage_exemplarise .left {
		margin-top:10px;
	}
#frame_abts {
	display:none;
	border:2px solid #777799;
	-moz-border-radius:10px;
	-webkit-border-radius:10px;
	border-radius:10px;
	padding:10px;
	z-Index:1000;
	position:absolute;
	background: #eee;
	width:190px;
	height:250px;
}
	body.abonnement_parution_edition .left {
		margin-top:10px;
	}
#frame_trans_expls{
	display:none;
	border:2px solid #777799;
	-moz-border-radius:10px;
	-webkit-border-radius:10px;
	border-radius:10px; 
	padding:10px;
	z-Index:1000;
	position:absolute;
	background: #eee;
	width:500px;
	height:250px;
}

#a_recevoirChild .colonne_suite input {margin-right:20px;}

.form-acquisition>.form-contenu #tot_ht, #tot_tva, #tot_ttc, #adr_fou, #adr_liv, #adr_fac, #tot_expl, #devise[class=saisie-5emd]{	
	border: 1px inset #aaa;
}


.req_cell {
	table-layout:fixed;
	text-align: left;
}

.req_cell th,
.req_cell td {
	border:1px solid #000000;
	border-collapse:collapse;
	padding-right:4px;	
}
.req_cell .col_ali{width:10%;}

.req_cell .col_get,
.req_cell .col_vis,
.req_cell .col_grp,
.req_cell .col_tri {
	width:20px;
	padding-right:0px;
}
.req_cell .col_act,
.req_cell .col_obl {
	width:50px;
	padding-right:0px;
}
.req_cell .up_bt {
	vertical-align:top;
	cursor:pointer;	
}
.req_cell .down_bt {
	vertical-align:bottom;
	margin-left:-16px;
	cursor:pointer;	
}
.req_cell .stop_bt,
.req_cell .cross_bt {
	vertical-align:middle;
	width:16px;
	cursor:pointer;	
}
.in_cell,
.in_cell_nb,
.in_cell_ro,
.in_cell_nb_ro {
	width:99%;
	border:1px inset;
}
.in_cell_nb,
.in_cell_nb_ro {
	text-align:right;
}
.in_cell_ro,
.in_cell_nb_ro {	
	background-color: #90B636;
	border: 2px inset #aaa;
}

.in_cell_text {
	width:95%;
	border:1px solid;
}
.in_cell_rd,
.in_cell_ld {
	width:100%;	
	background-color:transparent;
	border-color:transparent;
	border-width:0;
}
.in_cell_rd {
	text-align:right;	
}
.in_cell_ld {
	text-align:left;
}

.req_ajax_div {
	display:none;
	border:1px #000 solid;
	left:0px;
	top:0px;
	position:absolute;
	background-color:#FFFFFF;
	z-Index:1000;
	height:200px;
	overflow:auto;
}

.req_row_handler {
	margin-left:5px;
	top:0px;
	cursor:pointer;	
}

#req_frame {
	display:none;
	border:2px solid #777799;
	-moz-border-radius:10px;
	-webkit-border-radius:10px;
	border-radius:10px;
	padding:5px;
	z-Index:1000;
	position:absolute;
	background: #FFF0A7;
 }

 .req_cell .bt_cross_elt {
 	vertical-align:bottom;
 	width:8px;
	cursor:pointer;
 }

 .act_cell {
	table-layout:fixed;
}
.act_cell th,
.act_cell td {
	border:1px solid #000000;
	border-collapse:collapse;
	padding-left:2px;
	padding-right:2px;
	vertical-align:top;	
	overflow:hidden;
}
.act_cell_chkbox {
	width:25px;
}
.act_cell_img_plus {
	background:#8cc6ff;
	margin-left:-20px;
}
.act_cell_chkbox2 {
	margin-right:-20px;
}
.act_cell_comments table,
.act_cell_reminders table
{
	margin-top:0px;
	margin-bottom:0px;
}

.act_cell_comments tr,
.act_cell_reminders tr {
	background : #DDDDDD;
}
.act_cell_comments td,
.act_cell_reminders td
{
	margin-top:0px;
	margin-bottom:0px;
	border:none;
}

/**
/**
 *  Couleur de fond et de liens du calendrier
 *
 **/
#calendrier_tab td.lien_date a{
	color:white;
}
#calendrier_tab td.lien_date {
	background:green;
}
#calendrier_tab td.lien_date_hs {
	background:red;
}
#calendrier_tab td.lien_date_hs_p {
	background:orange;
}

 .recorded {
	color: #cc0000;
	font-weight: bold;
}
.pbar {
	width:710px;
	text-align:center;
}
.pbar_frame {
	border:#000000 1px solid;
	padding:4px;
}
.pbar_gauge {
	text-align:left;
}
#pbar_img {
	height: 16px;
	width:0px;
}

.dom_div {
	overflow:auto;
}
.dom_tab {
	table-layout:fixed;	
}
.dom_col {
	overflow:hidden;
	width:200px;
}
.dom_cell_tab {
	border:#000000 1px solid;
	overflow:hidden;
}

.dom_tab2 {
	display: table;
}
.dom_row2 {
	display: table-row;
	height: 100px;
}
.dom_col2 {
	display: table-cell;
}
.dom_cell2_h {
	display: block;
	width: 200px;
	height: 100px;
	overflow: hidden;
	border: 1px solid #AAAAAA;
	background-color: #CCCCCC;
	font-weight: bold;
	text-align: center;
}
.dom_cell2 {
	display: block;
	height: 100px;
	overflow: hidden;
	border: 1px solid #AAAAAA;
}
.dom_sel {
	width: 190px;
}
/*Suggestions multiples */
.tab_sug{
	table-layout: fixed;
}

.tab_sug th, .tab_sug td{
	border:1px solid #CCCCCC;	
/*	vertical-align:center;*/
	text-align: center;
	overflow:scroll;
	width:100%;
}

.tab_sug  input, .tab_sug textarea{
   width:95%;
   height:100%;
   background:#F3F3F3;
}
.tab_sug select{
	width:95%;
}


.erreur_saisie {
	background-color: #ff0000;
}

table.sortable tr td {
	padding-top: 0px;
	padding-bottom: 0px;
	padding-left: 5px;
	padding-right: 5px;	
}

#recept_frame {
	border:2px solid #777799;
	border-radius:5px 5px;
	-moz-border-radius:10px;
	padding:5px;
	z-Index:1000;
	position:absolute;
	background: #EEEEEE;
	display:none;
}

	
/***************
 *     CMS     *
 **************/

.cms  #editorial_tree_container {
	min-height : 700px;
	overflow : visible;
}

.cms #editorial_tree_container .no_icon {
	background-image: none;
	width : 0px;
	height: 0px;	
	margin : 0px;
}

.cms form.cms_editorial_form {
	margin:0;
	width:auto;
}

.cms_logo_frame {
	vertical-align:middle;
	width:33em;
	height:3.6em;
	border:none;	
}

#f_ex_note, #f_ex_comment {
	width: 90%;
}

.notice-parent .left {
	margin-left: 5px;
    float: none;
}

.notice-parent .right {
	margin-top: -15px;
    text-align: right;
    float: none;
}

/************************************
 *     CATALOGUE - SEGMENTATION     *
 ***********************************/
 
 body.catalog #conteneur #contenu form #speech_timeline #speech_timeline_edit_menu ul {
	background-color: #EEEEEE;
    box-shadow: -1px 0 3px #999999 inset;
    border-radius: 5px;
    color: #000000;
    padding: 1px 3px;
    margin: 0px;
}

body.catalog #conteneur #contenu form #speech_timeline #speech_timeline_edit_menu ul li {
	background-color: #FFFEF5;
    box-shadow: -1px 0 3px #999999 inset;
    padding: 3px 10px;
    margin-bottom: 2px;
    margin-top: 2px;
    cursor: pointer;
    list-style-type: none;
}

body.catalog #conteneur #contenu form #speech_timeline #speech_timeline_edit_menu ul li:hover {
	background: url("images/menu_liens_hover.png") repeat-x scroll 0 0 #756D6C;
    color: #FFFFFF;
}
