/* +--------------------------------------------------------------------------+
// � 2002-2007 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: layout.css,v 1.73 2014-03-25 10:19:21 apetithomme Exp $
*/


body {
      margin:0;
      padding:0;
      color:#000;
      background:#FFFFFF;
}

html>body {font-size:small;}

 /*----	<NavBar>	----*/
#navbar {
	position:absolute;
	top:0;
	left:0;
 	margin: 2px;
	padding: 0.1em;
	width: 98%;
	height: 2em;
	}
#navbar h3
{
	display: none;
	width:1px;
}

#navbar ul {
	list-style-type: none;
	display: inline;
	height: 1.5em;
  margin: 0;
	}

#navbar li {
	padding: 1em 1em 0.2em 1em;
	display: inline;
	margin: 0 0.1em;
	}

#navbar li#current-tab {
	}

/*----	</NavBar>	----*/

#navbar li a,
#navbar li a:link,
#navbar li a:visited {
	color: #fff;
	font-weight:bold;
	background-color: #3580BD;
	}

#navbar li a:active {
	}

#navbar li a:hover {
	}

#navbar ul {
	border-bottom-color: #3580BC;
	border-top-color: #3580BC;
	border-left-color: #3580BC;
	border-right-color: #3580BC;
	}

#navbar li {
	border-color: #3580BC;
	background-color: #3580BD;
	}

#navbar li#current-tab {
	border-top-color: #3580BC;
	border-bottom-color: #3580BC;
	background-color: #15609C;
	border-left-color: #3580BC;
	border-right-color: #3580BC;
	}

#navbar li#current-tab a
#navbar li#current-tab a:link,
#navbar li#current-tab a:visited {
	color: #fff;
	background-color: #3580BC;
	}
	
/*	Menu	*/
#menu
{
	position: absolute;
	top: 5%;
	left: 0;
	width: 13em;
	text-align: left;
	padding: 0em;
}

#menu ul
{
	/*background: #fff no-repeat bottom left url(books_ul.gif);*/
	background: transparent;
	padding: 0px 0px 0px 0px;
	margin-left: .5em;
	margin-top: 4px;
	list-style-type: none;
}

#menu a
{
	display: block;
	text-decoration: none;
	color: #000;
	background: transparent;
	width: 12em;
	padding: 0 .1em;
}

#menu a:hover
{
	color: #000;
	text-decoration: underline;
}

#menu a:visited
{
	color: #000;
}

#menu li
{
	text-transform: lowercase;
	display: block;
	padding-bottom: .2em;
	color: #000;
	padding-left: 7px;
}

#menu ul li a
{
	text-decoration: underline;
}


#menu h3
{
	padding: 0px 0px 0px 0px;
	margin : 2px 0px 0px 0px;
/*	color: #86c71e;*/
	color :#000;
}
/*	/Menu	*/

/*    MENU : #menu_horizontal    */
	.hmenu span{
		padding:0 5px;
   	}
/*    MENU : #menu_vertical    */
	.vmenu span{
		display : block;
   	}
	/* General. setpref sert lors de l'enregistrement des preferences de disposition du menu. */
	#menu h3.setpref{
		background:#3580bd;
		color:white;
	}

/*	Contenu	*/
#contenu
{
	position: absolute;
	top: 0;
	right: 20px;
	left: 10.5em;
	/*width: 80%;*/
}

#contenu a
{
	color: #000;
	text-decoration: none;
}

		#contenu .hidelink a:link		{ text-decoration: none; }
		#contenu .hidelink a:visited	{ text-decoration: none; }
		/* utilis� pour les paniers : c'est un tag img avec un javascript onmousedown (pas un tag a) */
		#contenu .hidelink img			{ cursor: pointer; }
     

#contenu a:hover
{
	text-decoration: underline;
}

/*	Contenu	frame*/
#contenu-frame {
	position: absolute;
	top: 5%;
	right: 0;
	left: 0em;
	background:#FFFFFF;
	}

#contenu-frame a {
	color: #000;
	text-decoration: none;
	padding: 0 10px 0 0;
	}
#contenu-frame a:visited
{
	text-decoration: underline;
}

#contenu-frame a:hover
{
	text-decoration: underline;
}

#contenu-frame h1
{
	color : #452;
	padding-top: .5em;
}

#contenu-frame h2
{
	color : #000;
}

#contenu-frame TABLE {
	border:none;
}

#contenu-frame TD {
	border:none;
}

/*	/Contenu-frame	*/

#login-box,
#contenu label {
	}

/*	/Contenu	*/

/*	D�connexion	*/
#deconnexion a
{
	color: #f00;
}

#extra
{
	position: absolute;
	top: 0;
	right: 0;
	color: #000;
	text-transform: lowercase;
	padding: 10px 10px 0 0;
	z-index: 100;
}

#extra a
{
	color: #000;
}

#extra a:hover
{
	text-decoration: none;
}
/*	/D�connexion	*/



/*------------------------------------
/	Forms
/------------------------------------*/
table
{
	margin: 0px auto;
	width: 98%;
}

form
{
	margin: 0px auto;
	width: 98%;
}

.form-contenu,
table
{
	border-bottom: 1px solid #000;
	border-top: 1px solid #000;
	padding: 5px;
	margin-bottom: 2em;
	padding-bottom: 2em;
	padding-top: 1em;
	background-color: #fff;

}

form a
{
	color: #000;
	font-style: italic;
	text-decoration: underline;
}

form a:hover
{
	text-decoration: none;
}

/* formulaire de retour de document */
.form-retour-expl {
background: #BB0000;
color: #DDF0A7;
}
.form-retour-expl h3 {
color: #DDF0A7;
}

/*	/row	*/

select option,
select
{
	text-transform: lowercase;
	font-weight: bold;
}

/*------------------------------------
/*	tableaux
/------------------------------------*/
table
{
	background: #fff;
	border-collapse: collapse;
	border-right: 1px solid #000;
	border-left: 1px solid #000;
	width: 100%;
}

tr {
	font-style: normal;
}

th
{
	background: #f0f0f0;
	border-bottom: 2px solid #000;
	border-top: 2px solid #000;
	font-size: 9pt;
}
	th.brd {
		background: #f0f0f0;
		border-bottom: 2px solid #000;
		border-top: 2px solid #000;
		border-left: 1px solid #000;
		border-right: 1px solid #000;
		font-size: 9pt;
		text-align: left;
	}
	th.nobrd {
		background: #f0f0f0;
		border-bottom: 0px solid #000;
		border-top: 0px solid #000;
		border-left: 0px solid #000;
		border-right: 0px solid #000;
		font-size: 9pt;
		text-align: left;
	}

td
{
	border-bottom: 1px solid #000;
	border-top: 1px solid #000;
}
	td.brd {
		border-bottom: 1px solid #000;
		border-top: 1px solid #000;
		border-left: 1px solid #000;
		border-right: 1px solid #000;
		text-align: left;
		}
	td.brd2 {
		border-bottom: 1px solid #D5A085;
		border-top: 1px solid #D5A085;
		text-align: left;
		}


tr.even
{
	background: #bbf;
	color: #000;
}


tr.odd
{

}

tr.surbrillance 
{
	background: #aaf;
}

tr.justmodified 
{
	background-color: #000000;
	color: #ffffff;
	font-style: italic;
	font-weight: bold;
	
}

/*------------------------------------
/	/Forms
/------------------------------------*/

hr
{
	width:96%;
	height: 0;
	color: #fff;
	margin: 0;
	padding: 0;
	/*border-bottom: 1px solid #000;*/
}

/*	rounded corner box	*/

 .roundedCornerSpacer {
    margin: 0px; padding: 0px; border: 0px;
    clear: both;
    font-size: 1px; line-height: 1px;
}
/* In the CSS below, the numbers used are the following:
    1px: the width of the border
    3px: a fudge factor needed for IE5/win (see below)
    4px: the width of the border (1px) plus the 3px IE5/win fudge factor
    14px: the width or height of the border image
*/
.borderTL, .borderTR, .borderBL, .borderBR {
    width: 14px; height: 14px;
    padding: 0px; border: 0px;
}
.borderTL, .borderBL { float: left; clear: both; }
.borderTR, .borderBR { float: right; clear: right; }
.borderTL { margin: -1px 0px 0px -1px; }
.borderTR { margin: -1px -1px 0px 0px; }
.borderBL { margin: -14px 0px 0px 0px; }
.borderBR { margin: -14px 0px 0px 0px; }

/* IE5-5.5/win needs the border scooted to the left or right by an
   additional 3px! Why? */

.borderTL {
    margin-left: -4px;
    ma\rgin-left: -1px;
}
html>body .borderTL {
    margin-left: -1px;
}
.borderTR {
    margin-right: -4px;
    ma\rgin-right: -1px;
}
html>body .borderTR {
    margin-right: -1px;
}
.borderBL {
    margin-left: -3px;
    ma\rgin-left: 0px;
}
html>body .borderBL {
    margin-left: 0px;
}
.borderBR {
    margin-right: -3px;
    margin-right: 0px;
}
html>body .borderBR {
    margin-right: 0px;
}
/* To get around a known bug in IE5/win, apply the
   border (no margin, padding or positioning) to the
   content class and apply whatever positioning you
   want to the contentWrapper class. */

.content {
    margin: 0px;
    padding: 0px;
    border: 1px solid #00000;
}
.contentWrapper {
    /* position this div however you want, but
       keep its padding and border at zero */
    padding: 0px;
    border: 0px;
}

/*	/rounded corner box	*/

#login-box h1,
#contenu h1
{
	color :#000;
	padding-top: .5em;
	/*border-bottom: 1px dotted #000;*/
}

#contenu h2
{
	color : #000;
	font-size: 12pt;

	/*border-bottom: 1px dotted #000;*/
}

#image_recherche
{
	position: absolute;
	top: 23px;
	left:14em;
	/*background: url("loupe.gif") repeat left bottom;*/
	padding: 5px;
	margin: 0px auto;
	width: 60px;
	height:70px;
	z-index:25;
}


#footer
{
	display: none;
	float: right;
	padding: 0;
	margin: 0;
	z-index: 0;
}

#footer span,
#footer span a
{
	padding : 10px 0 0 5px;
	margin: 0 0 0 10px;

}
#footer a
{
	text-decoration: none;
}

#logo
{
	position: absolute;
	bottom: 0;
	left: -60px;
	/*background: transparent no-repeat bottom right url("books_small.gif");*/
	padding: 5px;
	margin: 0px auto;
	width: 200px;
	height:150px;
	z-index: 0;
}

#logo span
{
display:none;
}

@media screen {
#conteneur
{
	position: absolute;
	top: 3em;
	left:0;
	width: 100%;
	z-index:10;
}
}
#conteneur a
{
	color: #000;
	font-size: 10pt;
	text-decoration: none;
}

#conteneur a:hover
{
	text-decoration: underline;
}

img {
	border: 0;
	vertical-align: middle;
}

/***********************
 *	Classes g�n�riques
 ***********************/
.col
{
	float: left;
	width: 100%;
	padding: 1em;
	margin: 1em;
}

.erreur
{
	color: #f00;
	font-weight: bold;
	font-size: 16px;
}

.hide
{
	display: none;
}

.aide
{
	cursor: help;
}

.astuce,
{
	font-size: 10pt;
	margin-top: 1em;
}

.bool
{
	font-family: fixed;
	font-weight: bold;
}

.row
{
  clear: both;
}

.row img
{
	display: inline;
}

/* pour les champs en readonly, avec bouton parcourir */
.saisie-5emr,
.saisie-10emr,
.saisie-15emr,
.saisie-20emr,
.saisie-30emr,
.saisie-50emr,
.saisie-80emr
{
	background-color: #ccc;
	border: 1px solid #aaa;
}

/* pour les champs non modifiables */
.saisie-5emd,
.saisie-10emd,
.saisie-15emd,
.saisie-20emd,
.saisie-30emd,
.saisie-50emd,
.saisie-80emd
{	background-color:transparent;
	border-color:transparent;
	border-width:0;
}

.spacer
{
	clear: both;
	visibility: hidden;
	display: none;
	margin-bottom: -10px;
	margin-top: -10px;
}

.saisie-contenu
{
	padding-left: 12px;
	padding-top: .3em;
	margin-top: .2em;
}

.bouton
{
	color: #fff;
	font-weight: bold;
	border: 1px outset #aaa;
	background-color: #ccc;
}

.bouton:hover
{
	border-style: inset;
	background-color: #ccc;
 	border: 1px solid #ccc;	
}

#login-box
{
	width: 50%;
	margin-left: 25%;
	margin-right: 25%;
}

#login-box
{
	margin-top: 10%;
}

.erreur
{
	color: #f00;
}

.erreur-child
{
	display:none;
	margin-left: 12%;
    padding:0;
    color:#000;
    font-weight:normal;
}	

h3
{
	clear: both;
	display: block;
	margin-bottom: 1px;
	margin-top: 1px;
	padding-bottom: 1px;
	padding-top: 1px;
}

.notice-perio
{
	border-top: 1px solid #ccc;
	border-bottom: 1px solid #ccc;
	border-left: 1px solid #ccc;
	border-right: 1px solid #ccc;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;
}

.bulletins-perio
{
	border-top: 1px solid #ccc;
	border-bottom: 1px solid #ccc;
	border-left: 1px solid #ccc;
	border-right: 1px solid #ccc;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;
}

.bulletins-perio h2 blockquote {
		font-size:0.8em;
		font-weight: normal;
}	

.depouillements-perio
{
	border-top: 1px solid #ccc;
	border-bottom: 1px solid #ccc;
	border-left: 1px solid #ccc;
	border-right: 1px solid #ccc;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;
}
.msg-perio {
	font-size: 150%;
	font-weight: bold;
	color: #f00;	
}
/* barre fl�ch�e en p�rio */
.perio-barre {
	font-size: 120%;
	font-weight: bold;
}

/* classes pour l'affichage de liste d�pliantes en r�sultat de recherche*/
.notice-heada {
	text-decoration: none;
    font-size: 10pt;
    font-weight: bold;
}
.notice-parent {
    color: #000000;
    margin-left: 0px;
    font-size: 8pt;
    text-decoration: none
}
.notice-child {
	font-size: 0.9em;
    margin-left: 30px;
    margin-bottom: 20px;
    width: 98%;
    padding-left: 4px;
    padding-right: 4px;
    text-align: justify;
    border-bottom-style: solid;
    border-bottom-width: 1px;
    border-bottom-color: #c0c0c0;
    border-left-style: solid;
    border-left-width: 1px;
    border-left-color: #c0c0c0;
    border-right-style: none;
    border-top-style: none;
}

.notice-child table td img.img_notice {
    max-width: 140px;
	max-height: 200px;
	width: expression(this.width > 140 ? "140px" : true);
	height: expression(this.height > 200 ? "200px" : true);
}

table td .img_notice {
    max-width: 140px;
	max-height: 200px;
	width: expression(this.width > 140 ? "140px" : true);
	height: expression(this.height > 200 ? "200px" : true);
}

.notice-bu {
	margin-top: 0px;
	background-color: transparent;
	border-style: none;
}

/* classes pour l'affichage de liste d�pliantes en formulaire de saisie de notice */
.heada {
		font-size: 10pt;
		font-weight: bold;
		}
.parent {
	color: #000000;
	margin-left: 0px;
	font-size: 8pt;
	text-decoration: none
	}
.child {
	margin-left: 30px;
	}
.bu {
	margin-top: 15px;
	}

#el0Parent h3, 
#el1Parent h3,
#el2Parent h3,
#el3Parent h3,
#el230Parent h3,
#el4Parent h3,
#el5Parent h3,
#el6Parent h3,
#el7Parent h3,
#el8Parent h3,
#el9Parent h3,
#el10Parent h3,
#el11Parent h3,
#el30Parent h3,
#el41Parent h3,
#elbulParent h3,
#el14Parent h3  {
	margin-bottom: 0px;
	margin-top: -1px;
	}

.titre-panier
{
	border-top: 1px solid #ccc;
	border-bottom: 1px solid #ccc;
	border-left: 1px solid #ccc;
	border-right: 1px solid #ccc;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;
}

.table-no-border {
	border: none;
	}

table.docnum
{
	background: none;
	border-collapse: collapse;
	border-right: 0px ;
	border-left: 0px ;
	border-top: 0px ;
	border-bottom: 0px ;
	width: 98%;
}

td.docnum
{
	border-bottom: 0px solid #5450FF;
	border-top: 0px solid #5450FF;
	text-align: center;
}

.fond-mere {
	background-color: #4f72ff;
	}

.fond-article {
	background-color: #68df00;
	}
	
  iframe#alerte { 
	visibility:visible;position:absolute;
	left:0;top:600px;width:150px;height:100px;border-style:none;
	border-width:0px;border-color:#000000;
	background:#efe; 
	}
	

/* pour l'impression, des styles sont masqu�s*/
@media print {
  #conteneur 	{
		position: relative;
		clear:both;
		}

  #navbar
	{ display: none; }
  #menu
	{ display: none;}
 

  /*	Menu	*/
  #deconnexion 
	{ display: none; }
  #extra
	{ display: none; }
  .bouton
	{ display:none; }

  iframe#alerte
	{ visibility:hidden;	}
}

iframe#history {
	width:40%;
	height:97%;
	position:absolute; 
	top:1%; 
	left:1%;
	z-index:1000;
	}
	
* HTML iframe#history {
	height:580px;
	}

/* pour affichage de pav�s de couleur pour disinction des statuts de notices */
.statutnot1 {
	}
.statutnot2 {
	background-color: #BB0000;
	}
.statutnot3 {
	background-color: #00BB00;
	}
.statutnot4 {
	background-color: #0000BB;
	}
.statutnot5 {
	background-color: #D0686F;
	}
.statutnot6 {
	background-color: #A6DCDC;
	}
.statutnot7 {
	background-color: #816492;
	}
.statutnot8 {
	background-color: #BCB964;
	}
.statutnot9 {
	background-color: #6C75AC;
	}
.statutnot10 {
	background-color: #FFC587;
	}
.statutnot11 {
	background-color: #70C173;
	}
.statutnot12 {
	background-color: #660000;
	}
.statutnot13 {
	background-color: #006600;
	}
.statutnot14 {
	background-color: #000066;
	}
.statutnot15 {
	background-color: #80181F;
	}
.statutnot16 {
	background-color: #668C8C;
	}
.statutnot17 {
	background-color: #311442;
	}
.statutnot18 {
	background-color: #7C7914;
	}
.statutnot19 {
	background-color: #2C356C;
	}
.statutnot20 {
	background-color: #BF8547;
	}

.gris {
	color: grey;
}

.message_important {
	color: #f00;
	font-weight: bold;
	font-size: 1.5em;
	padding:5px;
	margin:5px;
	}

ul.sel_navbar {
      margin:5px;
      padding:0;
      list-style:none;
      clear:right;
      height:23px;
      float:left;
      margin-bottom:-1px;
	  border-bottom:1px solid #666666;  
}

ul.sel_navbar li {
	float:left;
	padding:3px 6px 0px 6px;
    border:1px solid #666666;  
    margin-right:4px;
	margin-bottom:5px;
    height:19px;
	background:#999999;
	color:#000000;
}

ul.sel_navbar li a {
	text-decoration:none;
	font-weight:normal;
	color:#000000;
}
      
ul.sel_navbar li.sel_navbar_current {
  	float:left;
  	padding:3px 6px 0px 6px;
  	background:#ffffff;
	border :1px solid #666666;  
	border-bottom:1px solid #ffffff;
	margin-bottom:4px;
    height:19px;
}
	
.dsi table tr td {
	border-left:1px solid #6F95CE;
	border-right:1px solid #6F95CE;
	border-bottom:1px solid #6F95CE;
}

.dsi table.dsi tr td:hover {
	background:#99f;
}


#frame_notice_preview {
 border:2px solid #777799;
 border-radius:5px 5px; 
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #F4EC92;
 display:none;
 width:680px;
 height:500px;
}

.edit #contenu tr.group_title {
	background: #bec0ce;
	}

#frame_periodique {
 border:2px solid #777799;
border-radius:5px 5px;
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #FFF0A7;
 display:none;
 width:190px;
 height:210px;
}

#expl-form select {
	width: 215px;
}
	
#frame_abts {
 border:2px solid #777799;
 border-radius:5px 5px;
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #FFF0A7;
 display:none;
 width:190px;
 height:250px;
}

#frame_trans_expls {
 border:2px solid #777799;
 border-radius:5px 5px;
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #ddf0a7;;
 display:none;
 width:500px;
 height:250px;
}

#a_recevoirChild .colonne_suite input {
	margin-right:20px;
}

.form-acquisition>.form-contenu #tot_ht, #tot_tva, #tot_ttc, #adr_fou, #adr_liv, #adr_fac, #tot_expl, #devise[class=saisie-5emd]{	
	border: 1px solid #aaa;
}
.req_cell {
	table-layout:fixed;
}
.req_cell th,
.req_cell td {
	border:1px solid #000000;
	border-collapse:collapse;
	padding-right:4px;	
}
.req_cell .col_ali {
	width:10%;
}
.req_cell .col_get,
.req_cell .col_vis,
.req_cell .col_grp,
.req_cell .col_tri {
	width:20px;
	padding-right:0px;
}
.req_cell .col_act,
.req_cell .col_obl {
	width:50px;
	padding-right:0px;
}
.req_cell .up_bt {
	vertical-align:top;
	cursor:pointer;	
}
.req_cell .down_bt {
	vertical-align:bottom;
	margin-left:-16px;
	cursor:pointer;	
}
.req_cell .stop_bt,
.req_cell .cross_bt {
	vertical-align:middle;
	width:16px;
	cursor:pointer;	
}
.in_cell,
.in_cell_nb,
.in_cell_ro,
.in_cell_nb_ro {
	width:99%;
	border:1px solid;
}
.in_cell_nb,
.in_cell_nb_ro {
	text-align:right;
}
.in_cell_ro,
.in_cell_nb_ro {	
	background-color: #CCC;
	border: 1px solid #684;
}

.in_cell_text{
	width:95%;
	border:1px solid;
}
.in_cell_rd,
.in_cell_ld {
	width:100%;	
	background-color:transparent;
	border-color:transparent;
	border-width:0;
}
.in_cell_rd {
	text-align:right;	
}
.in_cell_ld {
	text-align:left;
}

.req_ajax_div {
	border:1px #000 solid;
	left:0px;
	top:0px;
	position:absolute;
	background-color:#FFFFFF;
	z-Index:1000;
	height:200px;
	overflow:auto;
	display:none;
}

.req_row_handler {
	margin-left:5px;
	top:0px;
	cursor:pointer;	
}

#req_frame {
	border:2px solid #777799;
	border-radius:5px 5px;
	-moz-border-radius:10px;
	padding:5px;
	z-Index:1000;
	position:absolute;
	background: #FFF0A7;
	display:none;
 }

 .req_cell .bt_cross_elt {
 	vertical-align:bottom;
 	width:8px;
	cursor:pointer;
 }
 .act_cell th,
.act_cell td {
	border:1px solid #000000;
	border-collapse:collapse;
	padding-left:2px;
	padding-right:2px;
	vertical-align:top;	
	overflow:hidden;
}
.act_cell_chkbox {
	width:25px;
}  
.img_plus{background:#8cc6ff;}
.act_cell_img_plus {
	background:#8cc6ff;
	margin-left:-20px;
}
.act_cell_chkbox2 {
	margin-right:-20px;
}
.act_cell_comments table,
.act_cell_reminders table
{
	margin-top:0px;
	margin-bottom:0px;
}

.act_cell_comments,
.act_cell_reminders tr {
	background : #FFFFFF;
}
.act_cell_comments td,
.act_cell_reminders td
{
	margin-top:0px;
	margin-bottom:0px;
	border:none;
}


/**
 *  Couleur de fond et de liens du calendrier
 *
 **/
#calendrier_tab td.lien_date a{
	color:white;
}
#calendrier_tab td.lien_date {
	background:green;
}
#calendrier_tab td.lien_date_hs {
	background:red;
}
#calendrier_tab td.lien_date_hs_p {
	background:orange;
}
#up_frame{
	display:none;
	border:2px solid #777799;
	-moz-border-radius:10px;
	-webkit-border-radius:10px;
	border-radius:10px;
	padding:10px;
	z-Index:1000;
	position:absolute;
	background: #eee;
}
.recorded {
	color: #cc0000;
	font-weight: bold;
}
.pbar {
	width:710px;
	text-align:center;
}
.pbar_frame {
	border:#000000 1px solid;
	padding:4px;
}
.pbar_gauge {
	text-align:left;
}
#pbar_img {
	height: 16px;
	width:0px;
}
.dom_div {
	overflow:auto;
}
.dom_tab {
	table-layout:fixed;	
}
.dom_col {
	overflow:hidden;
	width:200px;
}
.dom_cell_tab {
	border:#000000 1px solid;
	overflow:hidden;
}

/*Suggestions multiples */
.tab_sug{
	table-layout: fixed;
}

table{
	border-collapse:collapse;
	margin: 10px 0;
	width:100%;
}
.tab_sug th, .tab_sug td{
	border:1px solid #CCCCCC;	
	/*vertical-align:center;*/
	text-align: center;
	overflow:scroll;
	width:100%;
}

.tab_sug  input, .tab_sug textarea{
   width:95%;
   height:100%;
   background:#F3F3F3;
}
.tab_sug select{
	width:95%;
}

.erreur_saisie {
	background-color: #ff0000;
}

table.sortable tr td {
	padding-top: 0px;
	padding-bottom: 0px;
	padding-left: 5px;
	padding-right: 5px;	
}

#recept_frame {
	border:2px solid #777799;
	border-radius:5px 5px;
	-moz-border-radius:10px;
	padding:5px;
	z-Index:1000;
	position:absolute;
	background: #FFFFFF;
	display:none;
}

#f_ex_note, #f_ex_comment {
	width: 90%;
}

body.alter h2 .bdd_version {
	font-size: 23px;
}

.notice-parent .left {
	margin-left: 5px;
    float: none;
}

.notice-parent .right {
	margin-top: -15px;
    text-align: right;
    float: none;
}

/***************************
* CATALOGUE - SEGMENTATION *
***************************/

body.catalog #conteneur #contenu form #speech_timeline #speech_timeline_edit_menu ul {
	background-color: #FFFFFF;
    box-shadow: -1px 0 3px #999999 inset;
    border-radius: 5px;
    color: #000000;
    text-transform: lowercase;
    text-decoration: underline;
    padding: 1px 3px;
    margin-left: -10.5em;
    margin-top: calc(-1.84em - 14pt);
}

body.catalog #conteneur #contenu form #speech_timeline #speech_timeline_edit_menu ul li {
	background-color: #FFFFFF;
    box-shadow: -1px 0 3px #999999 inset;
    padding: 3px 10px;
    margin-bottom: 2px;
    margin-top: 2px;
    cursor: pointer;
    list-style-type: none;
}